package jp.co.timedia.control;

import java.io.IOException;
import javax.servlet.*;
import javax.servlet.http.*;

abstract public class Controller {

    private Servlet servlet;
    private HttpServletRequest request;
    private HttpServletResponse response;
    private String action;

    public Controller() {
	init();
    }

    public void setAction(String action) {
	this.action = action;
    }

    public String getAction() {
        return action;
    }

    public void execute(Servlet servlet, HttpServletRequest request,
		HttpServletResponse response) throws IOException {
	this.servlet = servlet;
	this.request = request;
	this.response = response;
	redirect();
	process();
	setAction(null);
    }

    public HttpServletRequest getRequest() {
	return request;
    }

    public HttpServletResponse getResponse() {
	return response;
    }

    public HttpSession getSession() { 
	return getRequest().getSession();
    }

    public ServletContext getApplication() { 
	return servlet.getServletConfig().getServletContext();
    }

    private void redirect() throws IOException {
	if (getAction() == null) return;
	String actionURL = getActionList().get(getAction()).getUrl();
	if (actionURL == null)  return;
	if (getRequest().getRequestURI().equals(actionURL)) return;
	getResponse().sendRedirect(actionURL);
    }

    private void process() throws IOException {
	if (getAction() == null) return;
	getActionList().get(getAction()).execute(this);
    }  

    abstract protected void init();
    abstract protected ActionList getActionList();
 }

