package jp.co.timedia.shop.control;

import java.util.*;
import java.io.IOException;
import jp.co.timedia.control.*;
import jp.co.timedia.shop.model.*;

public class Shop extends Controller {

    private String catalogPage;
    private int catalogPageNumber;
    private static String CART = "cart";
    private static String CATALOG = "catalog";
    private static String CATALOG_FILE = "catalog.txt";

    public void setCatalogPage(String catalogPage) {
	this.catalogPage = catalogPage;
	try {
	    catalogPageNumber = Integer.parseInt(catalogPage);
	} catch (NumberFormatException e) {
	    catalogPageNumber = 0;
	}
    }

    public String getCatalogPage() {
        return catalogPage;
    }

    protected int getCatalogPageNumber() {
	return catalogPageNumber;
    }

    public boolean isPreviousPage() {
	return (getCatalogPageNumber() > 0);
    }

    public boolean isNextPage() throws IOException {
	return (getCatalogPageNumber() + 1 < getCatalog().getMaxPageNumber());
    }

    protected void previousPage() {
	if (isPreviousPage()) {
	    setCatalogPage(String.valueOf(catalogPageNumber - 1));
	} 
    } 

    protected void nextPage() throws IOException {
	if (isNextPage()) {
	    setCatalogPage(String.valueOf(catalogPageNumber + 1));
	} 
    } 

    protected void init() {
	catalogPage = "0";
    }

    public Iterator getCartIterator() {
	Cart cart = getCart();
	if (cart == null) return (new ArrayList()).iterator();
	return cart.getList().iterator();
    }

    public Iterator getCatalogIterator(String page) throws IOException {
	Catalog catalog = getCatalog();
	if (catalog == null) return (new ArrayList()).iterator();
	Cart cart = getCart();
	TreeMap list = catalog.getCatalog(page);
	Iterator iterator = getCartIterator();
	while (iterator.hasNext()) {
	    Item item = (Item) iterator.next();
	    if (list.get(item.getId()) != null) {
		list.put(item.getId(), item);
	    }
	}
	return list.values().iterator();
    }

    public String getTotal() {
	return getCart().getTotal();
    }

    protected Cart getCart() {
	Cart cart = (Cart) getSession().getAttribute(CART);
	if (cart == null) {
	    cart = new Cart();
	    getSession().setAttribute(CART, cart);
	}
	return cart;
    }

    protected Catalog getCatalog() throws IOException {
	Catalog catalog = (Catalog) getApplication().getAttribute(CATALOG);
	if (catalog == null) {
	    catalog = new Catalog();
	    catalog.load(getApplication().getRealPath("/"));
	    getApplication().setAttribute(CATALOG, catalog);
	}
	return catalog;
    }

    protected ActionList getActionList() {
	return new ShoppingActionList();	
    }

}

